@@ -1,11 +1,11 @@
 import React, { PureComponent } from 'react';
 
-import { LogsStreamLabels, LogRowModel } from 'app/core/logs_model';
 import { LogLabel } from './LogLabel';
+import { Labels, LogRowModel } from '@grafana/data';
 
 interface Props {
   getRows?: () => LogRowModel[];
-  labels: LogsStreamLabels;
+  labels: Labels;
   plain?: boolean;
   onClickLabel?: (label: string, value: string) => void;
 }
